import { formatAuditlogs, parseAuditlogsQuery, formatPageState, commonProcessor, formatDeployments, generateDeploymentsPath, parseDeploymentsQuery, formatDeviceSearch, generateDevicePath, parseDeviceQuery, formatReleases, generateReleasesPath, parseReleasesQuery, formatTenants, generateTenantPath, parseTenantsQuery } from './locationutils.cjs';

declare namespace defaultProcessors {
    namespace auditlogs {
        export { formatAuditlogs as format };
        export function locate(): undefined;
        export { parseAuditlogsQuery as parse };
    }
    namespace common {
        export { formatPageState as format };
        export function locate_1(): undefined;
        export { locate_1 as locate };
        export { commonProcessor as parse };
    }
    namespace deployments {
        export { formatDeployments as format };
        export { generateDeploymentsPath as locate };
        export { parseDeploymentsQuery as parse };
    }
    namespace devices {
        export { formatDeviceSearch as format };
        export { generateDevicePath as locate };
        export { parseDeviceQuery as parse };
    }
    namespace releases {
        export { formatReleases as format };
        export { generateReleasesPath as locate };
        export { parseReleasesQuery as parse };
    }
    namespace tenants {
        export { formatTenants as format };
        export { generateTenantPath as locate };
        export { parseTenantsQuery as parse };
    }
}
declare function useLocationParams(key: any, extras: any, processors?: {
    auditlogs: {
        format: ({ pageState }: {
            pageState: any;
        }, { today, tonight }: {
            today: any;
            tonight: any;
        }) => string;
        locate: () => undefined;
        parse: (params: any, { today, tonight }: {
            today: any;
            tonight: any;
        }) => {
            detail: any;
            endDate: any;
            startDate: any;
            type: any;
            user: any;
        };
    };
    common: {
        format: ({ selectedId, selectedIssues, page, perPage, sort }: {
            selectedId: any;
            selectedIssues: any;
            page: any;
            perPage: any;
            sort: any;
        }, { defaults }: {
            defaults: any;
        }) => string;
        locate: () => undefined;
        parse: (searchParams: any) => {
            pageState: {};
            params: URLSearchParams;
            sort: {} | undefined;
        };
    };
    deployments: {
        format: ({ deploymentObject, pageState }: {
            deploymentObject: any;
            pageState: any;
        }, { defaults, today, tonight }: {
            defaults: any;
            today: any;
            tonight: any;
        }) => string;
        locate: ({ pageState }: {
            pageState: any;
        }) => string;
        parse: (params: any, { pageState, location, tonight }: {
            pageState: any;
            location: any;
            tonight: any;
        }) => {
            deploymentObject: {};
            general: {
                showCreationDialog: boolean;
                showReportDialog: boolean;
                state: any;
            };
        };
    };
    devices: {
        format: ({ pageState, filters, selectedGroup }: {
            pageState: any;
            filters: any;
            selectedGroup: any;
        }) => string;
        locate: ({ pageState }: {
            pageState: any;
        }) => string;
        parse: (searchParams: any, extraProps?: {}) => {
            open: boolean;
            detailsTab: string | null;
            filters: any[];
            groupName: string;
        } | {
            open?: undefined;
            detailsTab: string | null;
            filters: any[];
            groupName: string;
        };
    };
    releases: {
        format: ({ pageState: { searchTerm, selectedTags, tab, type } }: {
            pageState: {
                searchTerm: any;
                selectedTags?: never[] | undefined;
                tab: any;
                type: any;
            };
        }) => string;
        locate: ({ pageState: { selectedRelease } }: {
            pageState: {
                selectedRelease: any;
            };
        }) => string;
        parse: (queryParams: any, extraProps: any) => {
            searchTerm: any;
            selectedRelease: string;
            tab: any;
            tags: any;
            type: any;
        };
    };
    tenants: {
        format: () => string;
        locate: ({ pageState: { selectedTenant } }: {
            pageState: {
                selectedTenant: any;
            };
        }) => string;
        parse: (queryParams: any, extraProps: any) => {
            name: any;
            selectedTenant: any;
        };
    };
}): any[];

export { defaultProcessors, useLocationParams };
